Archive of Appellate Court Opinions 2014 2013 | 2012 | 2011 | 2010 | 2009 | 2008 | 2007 | 2006 | 2005 | 2004 | 2003 | 2002 | 2001 | 2000
To Search: | Hit Control, F, on your keyboard, and enter the name.
Information on how to purchase the Connecticut Law Journal or the Connecticut Appellate Reports
Quick Links
Advance Release Opinions
Appellate Court Archive
Memorandum Archive
Supreme Court Archive
To be Published in Connecticut Law Journal of 7/22/14: AC36525 - In re Zen T. AC36298 - In re Yasiel R. AC36298 Concurrence - In re Yasiel R. AC35632 - U.S. Bank, N.A. v. Foote AC34674 - Marshall v. Marshall AC35725 - State v. Dickerson AC35468 - Good Earth Tree Care, Inc. v. Fairfield AC36406 - State v. Ross AC34789 - Howard v. Commissioner of Correction AC34763 - State v. Ruocco Published in Connecticut Law Journal of 7/15/14: AC35511 - State v. Carter AC35796 - Michos v. Planning & Zoning Commission AC35705 - Red Buff Rita, Inc. v. Moutinho AC35129 - Foote v. Commissioner of Correction AC35129 Concurrence - Foote v. Commissioner of Correction AC34349, AC34449 - Francis v. Commissioner of Correction AC33908 - State v. Zachary F. AC34788 - State v. Gemmell AC35306 - Coleman v. Coleman Published in Connecticut Law Journal of 7/8/14: AC35820, AC35821 - Baruno v. Slane AC35679 - DeNunzio v. DeNunzio AC35096 - Hirschfeld v. Machinist AC35096 Dissent - Hirschfeld v. Machinist AC36326 - Avery v. Medina AC34958 - Burns v. RBS Securities, Inc. AC35153 - State v. Salazar AC35278 - American Federation of State, County & Municipal Employees, Council 4, Local 1303-385 v. Westport Dept. of Public Works AC35118 - Abele Tractor & Equipment Co. v. Sono Stone & Gravel, LLC AC35648 - O’Hara v. Mackie AC35864 - Amos Financial, LLC v. Patel Published in Connecticut Law Journal of 7/1/14: AC34944 - Henderson v. State AC35038 - Lineberry v. Estevam AC35750 - State v. Inglis AC35352 - Cinotti v. Divers AC35770 - Bumbolow v. Foreman AC36011 - State v. Abushaqra AC35188 - Stepney, LLC v. JP Morgan Chase Bank, N.A. AC35550 - Hornblower v. Hornblower AC35624 - State v. Slaughter AC34463 - Melendez v. Commissioner of Correction AC35859 - RAB Performance Recoveries, LLC v. James AC35609 - New Haven v. G. L. Capasso, Inc AC35866 - Sullo Investments, LLC c. Moreau Published in Connecticut Law Journal of 6/24/14: AC35454 - Mukon v. Gollnick AC35835 - Newland v. Commissioner of Correction AC34292 - State v. Herring AC35656 - Weinstein & Wisser v. Cornelius AC35088 - State v. Gojcaj AC35455 - Harlow v. Stickels AC35367 - Martinez v. Empire Fire & Marine Ins. Co. AC35906 - Murcia v. Geyer AC35346 - Rodriguez v. Commissioner of Correction AC35374 - State v. Budziszewski Published in Connecticut Law Journal of 6/17/14: AC35754 - State v. James H. AC35312 - State v. Joseph AC34478 - State v. Jordan AC35823 - Stratford v. Wilson AC35825 - Stratford v. Winterbottom AC35702 - State v. Dzwonkowski AC36164 - Tyler v. Tyler AC35553 - State v. Anthony D. AC35740 - State v. Rodriguez Published in Connecticut Law Journal of 6/10/14: AC35224 - Kidder v. Read AC35631 - Stratford v. Sokol AC30600 - Equity One, Inc. v. Shivers AC34651 - Minor v. Commissioner of Correction AC35860 - Thivierge v. Witham AC34925 - Barlow v. Commissioner of Correction AC35054 - Escourse v. 100 Taylor Avenue, LLC AC35528 - Escourse v. 100 Taylor Avenue, LLC AC35345 - Caruso v. Zoning Board of Appeals AC35671 - Ramos v. J.J. Mottes Co. Published in Connecticut Law Journal of 6/3/14: AC35802 - Estate of Haburey v. Winchester AC35539 - Citimortgage, Inc. v. Rey AC35466 - Federal National Mortgage Assn. v. Bridgeport Portfolio, LLC AC35393 - State v. Smith AC35542 - State v. Dickson AC35462 - Palkimas v. State Farm Fire & Casualty Co. AC35791 - Wells Fargo Bank, N.A. v. Tarzia AC35417 - State v. Miller AC35483 - Lynwood Place, LLC v. Sandy Hook Hydro, LLC AC34724 - Blake v. Commissioner of Correction Published in Connecticut Law Journal of 5/27/14: AC35266 - U.S. Bank, N.A. v. Ugrin AC35347 - Brown v. State Farm Fire & Casualty Co. AC34940 - Cunniffe v. Cunniffe AC35285 - Gois v. Asaro AC34843 - State v. Solomon AC35633 - Chief Disciplinary Counsel v. Rozbicki AC35612 - Greenwood Manor, LLC v. Planning & Zoning Commission AC35400 - State v. Devon D. AC35543 - Clark v. Clark AC35143 - We the People of Connecticut, Inc. v. Malloy AC35752 - State v. Alex B. Published in Connecticut Law Journal of 5/20/14: AC35984 - In re Julie J. AC35423 - Morneau v. State AC35287 - East Windsor v. East Windsor Housing, Ltd. AC35288 - Ray Weiner, LLC v. Bridgeport AC34320 - Greenan v. Greenan AC35529 - Doyle v. Doyle AC35294 - State v. Jackson AC34752 - Hankerson v. Commissioner of Correction AC35332 - Perez v. Commissioner of Correction AC34903 - State v. Edge Published in Connecticut Law Journal of 5/13/14: AC35319 - Vazquez v. Buhl AC35045 - State v. Tenay AC34966 - Discover Bank v. Hill AC35416 - Christophersen v. Christophersen AC34666 - Shefelbine v. Commissioner of Correction AC34759 - Heath v. Heath AC34367 - Ramey v. Commissioner of Correction AC34367 Dissent - Ramey v. Commissioner of Correction AC35643 - Emerick v. Dept. of Public Health AC35729 - Clelford v. Bristol Published in Connecticut Law Journal of 5/6/14: AC36068 - In re Daniel A. AC35735 - Princess Q. H. v. Robert H. AC34363 - R.I. Pools, Inc. v. Paramount Concrete, Inc. AC35464 - Yorgensen v. Chapdelaine AC35303 - Spatta v. American Classic Cars, LLC AC33515 - Patterson v. Commissioner of Correction AC34551 - Russell v. Commissioner of Correction AC35467 - Valenzisi v. Connecticut Education Assn. AC34400 - Wilson v. Commissioner of Correction AC34914 - Chester v. Manis AC35156 - Tittle v. Skipp-Tittle AC34602 - Connecticut Housing Finance Authority v. Muhammad AC34876 - Guerra v. State/li> Published in Connecticut Law Journal of 4/29/14: AC35490 - Wright v. Leonardi AC35474 - Snyder v. Gladeview Health Care Center AC35736 - Disciplinary Counsel v. Snaider AC33894 - State v. Wright AC35803 - Amato v. Hearst Corp. AC35149 - Deutsche Bank Trust Co. Americas DeGennaro AC35149 Concurrence - Deutsche Bank Trust Co. Americas DeGennaro AC35559 - JPMorgan Chase Bank, N.A. v. Georgitseas AC35826 - Valentine v. Valentine AC35361 - Connelly v. Commissioner of Correction AC35657 - State v. Johnson Published in Connecticut Law Journal of 4/22/14: AC34673 - Matthews v. SBA, Inc. AC35383 - Longview Estates, LLC v. Woodin AC35541 - MacDermid, Inc. v. Cookson Group, PLC AC35058 - State v. Jeremy D. AC34350 - Torres v. Carrese AC35695 - JMS Newberry, LLC v. Kaman Aerospace Corp. AC34872 - Keenan v. Casillo AC35399 - State v. Bellamy AC33343 - Jackson v. Commissioner of Correction AC34406 - State v. Denya AC33828, AC33829 - Coleman v. Commissioner of Correction Published in Connecticut Law Journal of 4/15/14: AC35253 - Wells Fargo Bank, N.A. v. Strong AC35571 - State v. Campbell AC35085 - Czajkowski v. YMCA of Metropolitan Hartford, Inc. AC35357, AC35358 - Villages, LLC v. Enfield Planning & Zoning Commission AC34950 - Fairfield Merrittview Ltd. Partnership v. Norwalk AC35262 - Passalugo v. Guida-Seibert Dairy Co. AC35157 - Pachaug Marina & Campground Assn., Inc. v. Pease AC34851 - Delvecchio v. Commissioner of Correction AC35436 - Di Teresi v. Stamford Health System, Inc. Published in Connecticut Law Journal of 4/8/14: AC36083 - In re Zen T. AC34234 - Meadowbrook Center, Inc. v. Buchman AC34234 Concurrence - Meadowbrook Center, Inc. v. Buchman AC35482 - Manning v. Feltman AC35482 Concurrence - Manning v. Feltman AC35427 - Silver v. Holtman AC35427 Dissent - Silver v. Holtman AC35302 - Gaynor v. Hi-Tech Homes AC35302 Dissent - Gaynor v. Hi-Tech Homes AC34990 - Gleason v. Smolinski AC35208 - Martowska v. White AC34643, AC34644 - Herasimovich v. Wallingford AC34613 - State v. Graham S. AC34961 - Cimmino v. Marcoccia AC34932 - State v. King Published in Connecticut Law Journal of 4/1/14: AC31575, AC31576 - Deane v. Kahn AC34639 - State v. Cancel AC34985 - Frauenglass & Associates, LLC v. Enagbare AC35439 - Frances Erica Lane, Inc. v. Board of Zoning Appeals AC34863 - State v. Chiclana AC34529 - State v. Smith AC35759 - Ginsberg & Ginsberg, LLC v. Alexandria Estates, LLC AC34415 - Quiroga v. Commissioner of Correction Published in Connecticut Law Journal of 3/25/14: AC34957 - Rousseau v. Perricone AC34425 - Martin V. v. Commissioner of Correction AC35167 - Perugini v. Giuliano AC34777 - Manka v. Walt Disney Co. AC35372 - Crespo v. Commissioner of Correction AC35838 - Deutsche Bank National Trust Co. v. Torres AC35264 - State v. Montanez AC35982 - State v. Grant AC34604 - Perillo v. Commissioner of Correction Published in Connecticut Law Journal of 3/18/14: AC33542 - State v. Smith AC33542 Concurrence - State v. Smith AC35245 - Sean O’Kane A.I.A. Architect, P.C. v. Puljic AC34521 - Cammarota v. Guerrera AC34279 - State v. Edwards AC35572 - State v. Lisboa AC35127 - Carmon v. Commissioner of Correction AC35753 - State v. Francis AC33746 - Antonio A. v. Commissioner of Correction Published in Connecticut Law Journal of 3/11/14: AC35856 - In re Paul M. AC35811 - In re Kasmaesha C. AC35419 - State v. Brundage AC34701 - State v. Francis AC34096 - Walker v. Housing Authority AC35242 - Traylor v. Gerratana AC34756 - Bochanis v. Sweeney AC35220 - Russell v. Mitchell Properties, Inc. AC34959 - Anderson v. Commissioner of Correction AC35460 - Devone v. Finley Published in Connecticut Law Journal of 3/4/14: AC34656 - Rostad v. Hirsch AC35068, AC35069, AC35070, AC35072, AC35073 - Konover Residential Corp. v. Elazazy AC35068, AC35069, AC35070, AC35072, AC35073 - Konover Residential Corp. v. Khan AC35068, AC35069, AC35070, AC35072, AC35073 - Konover Residential Corp. v. Torriero AC35068, AC35069, AC35070, AC35072, AC35073 - Konover Residential Corp. v. Stolarczyk AC35068, AC35069, AC35070, AC35072, AC35073 - Konover Residential Corp. v. Syed AC35465 - Customers Bank v. Boxer AC34678 - Camacho v. Commissioner of Correction. AC34814 - State v. LeBlanc AC35389 - State v. Lewis AC34321 - Smith v. Commissioner of Correction AC35983 - State v. Gaffney AC35164 - Chen v. Hopkins School, Inc. Published in Connecticut Law Journal of 2/25/14: AC35201, AC35270 - Henderson v. Lagoudis AC34987 - Shevlin v. Civil Service Commission AC34601 - R.S. Silver Enterprises, Inc. v. Pascarella AC24729 - O’Toole v. Eyelets for Industry, Inc. AC34642 - State v. Hector M. AC34392 - State v. Donald H. G. AC34267 - Staton v. Commissioner of Correction AC35397 - Colon v. Autozone Northeast, Inc. Published in Connecticut Law Journal of 2/18/14: AC35819 - In re Shane M. AC35388 - State v. Jessie L. C. AC35257 - Lagueux v. Leonardi AC35257 Dissent - Lagueux v. Leonardi AC34830 - Aliano v. Aliano AC35032 - Talbot v. Talbot AC35042 - Generation Partners, L.P. v. Mandell AC35354 - Wells Fargo Bank Minnesota, N.A. v. Russo Published in Connecticut Law Journal of 2/11/14: AC35785 - In re Natalie J. AC35094 - O’Donnell v. Bozzuti AC34298 - Three Levels Corp. v. Conservation Commission AC34248 - State v. Damone AC35323 - Scalise v. East Greyrock, LLC AC35456 - Scalise v. Cummings & Lockwood, LLC AC35194 - Nikides v. Wethersfield Published in Connecticut Law Journal of 2/4/14: AC34726 - Wells Fargo Bank, N.A. v. Melahn AC34314 - Brown v. Brown AC35985 - Thomas v. Primus AC34343 - Treglia v. Santa Fuel, Inc. AC34703 - State v. Flores AC35274 - Gordon v. Gordon AC35594 - Morneau v. State AC34264 - Cornfield Associates Ltd. Partnership v. Cummings Published in Connecticut Law Journal of 1/28/14: AC35573 - In re Kyara H. AC35506 - In re Kyara H. AC35199 - Perez v. Minore AC30979 - Holmes v. Hartford Hospital AC35265 - Hinde v. Specialized Education of Connecticut, Inc. AC34568 - Mozell v. Commissioner of Correction AC35109 - State v. Maner AC34880 - Mekrut v. Suits AC35554 - State v. Sease AC34960 - Percy v. Lamar Central Outdoor, LLC Published in Connecticut Law Journal of 1/21/14: AC33653 - State v. Daniel G. AC33653 Dissent - State v. Daniel G. AC35401 - State v. Collins AC34393 - State v. Chance AC35155 - Roe #1 v. Boy Scouts of America Corp. AC34610 - Pellecchia v. Connecticut Light & Power Co. AC35171 - Resso v. Administrator, Unemployment Compensation Act AC33827 - Garcia v. Commissioner of Correction AC35076 - Nikola v. 2938 Fairfield, LLC AC34533 - State v. Rosado Published in Connecticut Law Journal of 1/14/14: AC34716 - Recall Total Information Management, Inc. v. Federal Ins. Co. AC34598 - State v. Obas AC33762 - Mark v. Neundorf AC35340 - American Tax Funding, LLC v. Basher AC33398 - Linarte v. Commissioner of Correction AC34983 - State v. Holder AC34562 - Wright v. Commissioner of Correction AC34992 - Baker-Grenier v. Grenier AC33910 - Little v. Commissioner of Correction Published in Connecticut Law Journal of 1/7/14: AC35756 - In re Sena W.
Attorneys | Case Look-up | Courts | Directories | Educational Resources | E-Services | Español | FAQ's | Juror Information | Media | Opinions | Opportunities | Self-Help | Home Common Legal Words | Contact Us | Site Map | Website Polices and Disclaimers Copyright © 2014, State of Connecticut Judicial Branch